config = {
  "production": {
    "api": {
      "url": "https://api.inscribe.ai",
    }
  },
  "staging": {
    "api": {
      "url": "https://staging-api.inscribe.ai",
    }
  },
  "development": {
    "api": {
      "url": "https://local-api.inscribe.ai",
    }
  },
  "test": {
    "api": {
      "url": "http://127.0.0.1:8001",
    }
  }
}
